/*******************************************************************************
*  Copyright 2004-2011 NetApp, Inc.
*
* This program is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by the
* Free Software Foundation,  version 2 of the License.
*
* This program is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
********************************************************************************/
/*******************************************************************************

NAME            mppLnx26p_shared.h
SUMMARY         %description%
VERSION         %version: 9 %
UPDATE DATE     %date_modified: Tue Dec 20 12:46:22 2011 %
PROGRAMMER      %created_by:    babum %


DESCRIPTION:
   This header file contains definitions that are shared by the Linux MPP
   virtual HBA driver and the Linux MPP upper level driver. The definitions,
   which are defined in this header file, are not used by the MPP common APIs.
INCLUDE FILES:

NOTES:

RESTRICTIONS:

SEE ALSO:

REFERENCE:

IMPLEMENTATION:

MODIFICATION HISTORY:

*******************************************************************************/


#ifndef __INCmppLnx26p_shared
#define __INCmppLnx26p_shared


/***  INCLUDES  ***/
#include "MPP_Common.h"


/***  CONSTANT DEFINITIONS  ***/
#define MPPLNX_PROC_NAME               "mpp"

/***  MACRO DEFINITIONS  ***/
/***  GLOBALS  ***/
extern struct mpp_Config_Parameters mppLnx_Config_Parameters;

/***  FUNCTION DECLARATION ***/
extern VOID mpp_ConvertWWNtoAscii(BYTE *AsciiWWN, BYTE *ArrayWWN);

typedef enum
{
    ADD_DEVICE,
    DEL_DEVICE
} HOT_PLUG_TYPE;

typedef struct _mpp_hot_plug_event
{
    struct  list_head       list;
    struct scsi_device      *device;
    spinlock_t      *hot_plug_lock;
    HOT_PLUG_TYPE           event_type;
} mpp_hot_plug_event;

extern struct list_head mpp_hot_plug_list;
extern spinlock_t mpp_hot_plug_spin_lock;

static inline int 
mppLnx_refcnt_atomic_inc(LunPathInfo_t *lunPathInfo)
{
    unsigned long flags;
    int rc;

    MPP_LOCK(lunPathInfo->Lock, flags);
    lunPathInfo->refCount++;
    rc = lunPathInfo->refCount;
    MPP_UNLOCK(lunPathInfo->Lock, flags);

    return rc;
}

static inline int 
mppLnx_refcnt_atomic_dec(LunPathInfo_t *lunPathInfo)
{
    unsigned long flags;
    int rc;

    MPP_LOCK(lunPathInfo->Lock, flags);
    lunPathInfo->refCount--;
    rc = lunPathInfo->refCount;
    MPP_UNLOCK(lunPathInfo->Lock, flags);

    return rc;
}

static inline int 
mppLnx_refcnt_atomic_get(LunPathInfo_t *lunPathInfo)
{
    unsigned long flags;
    int rc;

    MPP_LOCK(lunPathInfo->Lock, flags);
    rc = lunPathInfo->refCount;
    MPP_UNLOCK(lunPathInfo->Lock, flags);

    return rc;
}

#endif        /* End of __INCmppLnx26p_shared  */
